@@ -1,7 +1,32 @@
+##  Copyright (C) 2010 John Verzani
+##
+##  This program is free software; you can redistribute it and/or modify
+##  it under the terms of the GNU General Public License as published by
+##  the Free Software Foundation; either version 2 of the License, or
+##  (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##  GNU General Public License for more details.
+##
+##  A copy of the GNU General Public License is available at
+##  http://www.r-project.org/Licenses/
+
 ## XXX no methods defined here!!!
+
+##' Menubar implementation
+##' 
+##' @param menulist list of actions. Actions must have parent specified
+##' @param popup ignored. Logical indicating if this is a popup widget
+##' @param action parameterizes handler in action
+##' @param container parent container
+##' @param ... passed to add method of parent container
+##' @export
 gmenu <- function(menulist,  popup = FALSE, action=NULL, container = NULL,...) {
+
   if(popup) {
-    warning("IMPLEMENT POPUP")
+    warning("gmenu: popup is not implemented")
     return()
   }
   
