@@ -1,3 +1,5 @@
+## combobox examples
+
 w <- gwindow("Test of gcombobox")
 g <- ggroup(cont=w, horizontal=FALSE)
 
@@ -6,7 +8,7 @@ handler <- function(h,...) gmessage(svalue(h$action), parent=g)
 
 m <- data.frame(
   values = state.name,
-  icons = rep("images/home.gif",50),
+  icons = convertStaticFileToUrl(getStockIcons()[[1]]),
   gtip = paste(state.abb,"has",state.area,"square miles.", sep=" ")
   )
 
